@@ -18,8 +18,9 @@ Key manager implementation for Barbican
 """
 import calendar
 import time
-import urllib
 
+from barbicanclient import client as barbican_client_import
+from barbicanclient import exceptions as barbican_exceptions
 from cryptography.hazmat import backends
 from cryptography.hazmat.primitives import serialization
 from cryptography import x509 as cryptography_x509
@@ -28,27 +29,27 @@ from keystoneauth1 import loading
 from keystoneauth1 import service_token
 from keystoneauth1 import session
 from oslo_config import cfg
+from oslo_context import context as oslo_context
 from oslo_log import log as logging
 from oslo_utils import excutils
+from oslo_utils import timeutils
 
+from castellan.common.credentials import keystone_password
+from castellan.common.credentials import keystone_token
 from castellan.common import exception
 from castellan.common.objects import key as key_base_class
 from castellan.common.objects import opaque_data as op_data
 from castellan.i18n import _
 from castellan.key_manager import key_manager
 
-from barbicanclient import client as barbican_client_import
-from barbicanclient import exceptions as barbican_exceptions
-from oslo_utils import timeutils
-
 
 _barbican_opts = [
-    cfg.StrOpt('barbican_endpoint',
+    cfg.URIOpt('barbican_endpoint',
                help='Use this endpoint to connect to Barbican, for example: '
                     '"http://localhost:9311/"'),
     cfg.StrOpt('barbican_api_version',
                help='Version of the Barbican API, for example: "v1"'),
-    cfg.StrOpt('auth_endpoint',
+    cfg.URIOpt('auth_endpoint',
                default='http://localhost/identity/v3',
                deprecated_name='auth_url',
                deprecated_group='key_manager',
@@ -106,8 +107,6 @@ class BarbicanKeyManager(key_manager.KeyManager):
     """Key Manager Interface that wraps the Barbican client API."""
 
     def __init__(self, configuration):
-        self._barbican_client = None
-        self._base_url = None
         self.conf = configuration
         self.conf.register_opts(_barbican_opts, group=_BARBICAN_OPT_GROUP)
         loading.register_session_conf_options(self.conf, _BARBICAN_OPT_GROUP)
@@ -116,6 +115,9 @@ class BarbicanKeyManager(key_manager.KeyManager):
                                               _BARBICAN_SERVICE_USER_OPT_GROUP)
         loading.register_auth_conf_options(self.conf,
                                            _BARBICAN_SERVICE_USER_OPT_GROUP)
+        verify_ssl = self.conf.barbican.verify_ssl
+        verify_ssl_path = self.conf.barbican.verify_ssl_path
+        self._verify = verify_ssl and (verify_ssl_path or verify_ssl)
 
     def _get_barbican_client(self, context):
         """Creates a client to connect to the Barbican service.
@@ -133,21 +135,15 @@ class BarbicanKeyManager(key_manager.KeyManager):
             LOG.error(msg)
             raise exception.Forbidden(msg)
 
-        if self._barbican_client and self._current_context == context:
-            return self._barbican_client
-
         try:
             auth = self._get_keystone_auth(context)
-            verify_ssl = self.conf.barbican.verify_ssl
-            verify_ssl_path = self.conf.barbican.verify_ssl_path
-            verify = verify_ssl and verify_ssl_path or verify_ssl
-            sess = session.Session(auth=auth, verify=verify)
+            sess = session.Session(auth=auth, verify=self._verify)
 
-            self._barbican_endpoint = self._get_barbican_endpoint(auth, sess)
-            self._barbican_client = barbican_client_import.Client(
+            endpoint = self._get_barbican_endpoint(auth, sess)
+            return barbican_client_import.Client(
+                version=self.conf.barbican.barbican_api_version,
                 session=sess,
-                endpoint=self._barbican_endpoint)
-            self._current_context = context
+                endpoint=endpoint)
 
         # TODO(pbourke): more fine grained exception handling - we are eating
         # tracebacks here
@@ -155,13 +151,8 @@ class BarbicanKeyManager(key_manager.KeyManager):
             LOG.error("Error creating Barbican client: %s", e)
             raise exception.KeyManagerError(reason=e)
 
-        self._base_url = self._create_base_url(auth,
-                                               sess,
-                                               self._barbican_endpoint)
-        return self._barbican_client
-
     def _get_keystone_auth(self, context):
-        if context.__class__.__name__ == 'KeystonePassword':
+        if isinstance(context, keystone_password.KeystonePassword):
             auth = identity.Password(
                 auth_url=context.auth_url,
                 username=context.username,
@@ -177,7 +168,7 @@ class BarbicanKeyManager(key_manager.KeyManager):
                 project_domain_id=context.project_domain_id,
                 project_domain_name=context.project_domain_name,
                 reauthenticate=context.reauthenticate)
-        elif context.__class__.__name__ == 'KeystoneToken':
+        elif isinstance(context, keystone_token.KeystoneToken):
             auth = identity.Token(
                 auth_url=context.auth_url,
                 token=context.token,
@@ -191,7 +182,7 @@ class BarbicanKeyManager(key_manager.KeyManager):
                 reauthenticate=context.reauthenticate)
         # this will be kept for oslo.context compatibility until
         # projects begin to use utils.credential_factory
-        elif context.__class__.__name__ == 'RequestContext':
+        elif isinstance(context, oslo_context.RequestContext):
             if getattr(context, 'get_auth_plugin', None):
                 auth = context.get_auth_plugin()
             else:
@@ -201,7 +192,10 @@ class BarbicanKeyManager(key_manager.KeyManager):
                     project_id=context.project_id,
                     project_name=context.project_name,
                     project_domain_id=context.project_domain_id,
-                    project_domain_name=context.project_domain_name)
+                    project_domain_name=context.project_domain_name,
+                    domain_id=context.domain_id,
+                    domain_name=context.domain_name,
+                    system_scope=context.system_scope)
         else:
             msg = _("context must be of type KeystonePassword, "
                     "KeystoneToken, or RequestContext.")
@@ -234,34 +228,19 @@ class BarbicanKeyManager(key_manager.KeyManager):
                 interface=self.conf.barbican.barbican_endpoint_type,
                 region_name=self.conf.barbican.barbican_region_name)
 
-    def _create_base_url(self, auth, sess, endpoint):
-        api_version = None
-        if self.conf.barbican.barbican_api_version:
-            api_version = self.conf.barbican.barbican_api_version
-        elif getattr(auth, 'service_catalog', None):
-            endpoint_data = auth.service_catalog.endpoint_data_for(
-                service_type='key-manager',
-                interface=self.conf.barbican.barbican_endpoint_type,
-                region_name=self.conf.barbican.barbican_region_name)
-            api_version = endpoint_data.api_version
-        elif getattr(auth, 'get_discovery', None):
-            discovery = auth.get_discovery(sess, url=endpoint)
-            raw_data = discovery.raw_version_data()
-            if len(raw_data) == 0:
-                msg = _(
-                    "Could not find discovery information for %s") % endpoint
-                LOG.error(msg)
-                raise exception.KeyManagerError(reason=msg)
-            latest_version = raw_data[-1]
-            api_version = latest_version.get('id')
+    def _delete_order(self, client, order_ref):
+        try:
+            client.orders.delete(order_ref)
+        except Exception as e:
+            LOG.warning("Failed to delete temporary order %s: %s",
+                        order_ref, e)
 
-        if endpoint[-1] != '/':
-            endpoint += '/'
-
-        base_url = urllib.parse.urljoin(
-            endpoint, api_version)
-
-        return base_url
+    def _delete_container(self, client, container_ref):
+        try:
+            client.containers.delete(container_ref)
+        except Exception as e:
+            LOG.warning("Failed to delete temporary container %s: %s",
+                        container_ref, e)
 
     def create_key(self, context, algorithm, length,
                    expiration=None, name=None):
@@ -286,7 +265,9 @@ class BarbicanKeyManager(key_manager.KeyManager):
                 expiration=expiration)
             order_ref = key_order.submit()
             order = self._get_active_order(barbican_client, order_ref)
-            return self._retrieve_secret_uuid(order.secret_ref)
+            secret_ref = self._retrieve_secret_uuid(order.secret_ref)
+            self._delete_order(barbican_client, order_ref)
+            return secret_ref
         except (barbican_exceptions.HTTPAuthError,
                 barbican_exceptions.HTTPClientError,
                 barbican_exceptions.HTTPServerError) as e:
@@ -324,6 +305,8 @@ class BarbicanKeyManager(key_manager.KeyManager):
                 container.secret_refs['private_key'])
             public_key_uuid = self._retrieve_secret_uuid(
                 container.secret_refs['public_key'])
+            self._delete_container(barbican_client, order.container_ref)
+            self._delete_order(barbican_client, order_ref)
             return private_key_uuid, public_key_uuid
         except (barbican_exceptions.HTTPAuthError,
                 barbican_exceptions.HTTPClientError,
@@ -410,20 +393,6 @@ class BarbicanKeyManager(key_manager.KeyManager):
             LOG.error("Error storing object: %s", e)
             raise exception.KeyManagerError(reason=e)
 
-    def _create_secret_ref(self, object_id):
-        """Creates the URL required for accessing a secret.
-
-        :param object_id: the UUID of the key to copy
-        :return: the URL of the requested secret
-        """
-        if not object_id:
-            msg = _("Key ID is None")
-            raise exception.KeyManagerError(reason=msg)
-        base_url = self._base_url
-        if base_url[-1] != '/':
-            base_url += '/'
-        return urllib.parse.urljoin(base_url, "secrets/" + object_id)
-
     def _get_active_order(self, barbican_client, order_ref):
         """Returns the order when it is active.
 
@@ -577,12 +546,13 @@ class BarbicanKeyManager(key_manager.KeyManager):
         :raises HTTPClientError: if object retrieval fails with 4xx
         :raises HTTPServerError: if object retrieval fails with 5xx
         """
+        if not object_id:
+            raise exception.KeyManagerError('key identifier not provided')
 
         barbican_client = self._get_barbican_client(context)
 
         try:
-            secret_ref = self._create_secret_ref(object_id)
-            return barbican_client.secrets.get(secret_ref)
+            return barbican_client.secrets.get(object_id)
         except (barbican_exceptions.HTTPAuthError,
                 barbican_exceptions.HTTPClientError,
                 barbican_exceptions.HTTPServerError) as e:
@@ -633,10 +603,12 @@ class BarbicanKeyManager(key_manager.KeyManager):
         :raises KeyManagerError: if object deletion fails
         :raises ManagedObjectNotFoundError: if the object could not be found
         """
+        if not managed_object_id:
+            raise exception.KeyManagerError('key identifier not provided')
+
         barbican_client = self._get_barbican_client(context)
         try:
-            secret_ref = self._create_secret_ref(managed_object_id)
-            barbican_client.secrets.delete(secret_ref, force)
+            barbican_client.secrets.delete(managed_object_id, force)
         except (barbican_exceptions.HTTPAuthError,
                 barbican_exceptions.HTTPClientError,
                 barbican_exceptions.HTTPServerError) as e:
@@ -658,11 +630,13 @@ class BarbicanKeyManager(key_manager.KeyManager):
         :raises ManagedObjectNotFoundError: if the object could not be found
         """
 
+        if not managed_object_id:
+            raise exception.KeyManagerError('key identifier not provided')
+
         barbican_client = self._get_barbican_client(context)
         try:
-            secret_ref = self._create_secret_ref(managed_object_id)
             barbican_client.secrets.register_consumer(
-                secret_ref, **consumer_data)
+                managed_object_id, **consumer_data)
 
         except (barbican_exceptions.HTTPAuthError,
                 barbican_exceptions.HTTPClientError,
@@ -675,12 +649,13 @@ class BarbicanKeyManager(key_manager.KeyManager):
                 raise exception.KeyManagerError(reason=e)
 
     def remove_consumer(self, context, managed_object_id, consumer_data):
+        if not managed_object_id:
+            raise exception.KeyManagerError('key identifier not provided')
 
         barbican_client = self._get_barbican_client(context)
         try:
-            secret_ref = self._create_secret_ref(managed_object_id)
             barbican_client.secrets.remove_consumer(
-                secret_ref, **consumer_data)
+                managed_object_id, **consumer_data)
         except (barbican_exceptions.HTTPAuthError,
                 barbican_exceptions.HTTPClientError,
                 barbican_exceptions.HTTPServerError) as e:
@@ -733,10 +708,12 @@ class BarbicanKeyManager(key_manager.KeyManager):
         return objects
 
     def list_options_for_discovery(self):
+        barbican_opts = _barbican_opts
+        barbican_opts += loading.get_session_conf_options()
         barbican_service_user_opts = loading.get_session_conf_options()
         barbican_service_user_opts += loading.get_auth_common_conf_options()
 
         return [
-            (_BARBICAN_OPT_GROUP, _barbican_opts),
+            (_BARBICAN_OPT_GROUP, barbican_opts),
             (_BARBICAN_SERVICE_USER_OPT_GROUP, barbican_service_user_opts),
         ]
