@@ -27,12 +27,13 @@ this class.
 """
 
 import binascii
+import copy
 import random
-import uuid
 
 from cryptography.hazmat import backends
 from cryptography.hazmat.primitives.asymmetric import rsa
 from cryptography.hazmat.primitives import serialization
+from oslo_utils import uuidutils
 
 from castellan.common import exception
 from castellan.common.objects import private_key as pri_key
@@ -67,7 +68,7 @@ class MockKeyManager(key_manager.KeyManager):
     def _generate_key(self, **kwargs):
         name = kwargs.get('name', None)
         algorithm = kwargs.get('algorithm', 'AES')
-        key_length = kwargs.get('key_length', 256)
+        key_length = kwargs.get('length', 256)
         _hex = self._generate_hex_key(key_length)
         return sym_key.SymmetricKey(
             algorithm,
@@ -150,9 +151,9 @@ class MockKeyManager(key_manager.KeyManager):
         return private_key_uuid, public_key_uuid
 
     def _generate_key_id(self):
-        key_id = str(uuid.uuid4())
+        key_id = uuidutils.generate_uuid()
         while key_id in self.keys:
-            key_id = str(uuid.uuid4())
+            key_id = uuidutils.generate_uuid()
 
         return key_id
 
@@ -162,11 +163,12 @@ class MockKeyManager(key_manager.KeyManager):
             raise exception.Forbidden()
 
         key_id = self._generate_key_id()
+        managed_object._id = key_id
         self.keys[key_id] = managed_object
 
         return key_id
 
-    def get(self, context, managed_object_id, **kwargs):
+    def get(self, context, managed_object_id, metadata_only=False, **kwargs):
         """Retrieves the key identified by the specified id.
 
         This implementation returns the key that is associated with the
@@ -176,7 +178,19 @@ class MockKeyManager(key_manager.KeyManager):
         if context is None:
             raise exception.Forbidden()
 
-        return self.keys[managed_object_id]
+        try:
+            obj = copy.deepcopy(self.keys[managed_object_id])
+        except KeyError:
+            raise exception.ManagedObjectNotFoundError(managed_object_id)
+
+        if metadata_only:
+            if hasattr(obj, "_key"):
+                obj._key = None
+            if hasattr(obj, "_data"):
+                obj._data = None
+            if hasattr(obj, "_passphrase"):
+                obj._passphrase = None
+        return obj
 
     def delete(self, context, managed_object_id, **kwargs):
         """Deletes the object identified by the specified id.
@@ -187,7 +201,26 @@ class MockKeyManager(key_manager.KeyManager):
         if context is None:
             raise exception.Forbidden()
 
-        del self.keys[managed_object_id]
+        try:
+            del self.keys[managed_object_id]
+        except KeyError:
+            raise exception.ManagedObjectNotFoundError(managed_object_id)
+
+    def add_consumer(self, context, managed_object_id, consumer_data):
+        if context is None:
+            raise exception.Forbidden()
+        if managed_object_id not in self.keys:
+            raise exception.ManagedObjectNotFoundError(managed_object_id)
+        self.keys[managed_object_id].consumers.append(consumer_data)
+
+    def remove_consumer(self, context, managed_object_id, consumer_data):
+        if context is None:
+            raise exception.Forbidden()
+        if managed_object_id not in self.keys:
+            raise exception.ManagedObjectNotFoundError(managed_object_id)
+        self.keys[managed_object_id].consumers = [
+            c for c in self.keys[managed_object_id].consumers
+            if c != consumer_data]
 
     def _generate_password(self, length, symbolgroups):
         """Generate a random password from the supplied symbol groups.
@@ -212,8 +245,24 @@ class MockKeyManager(key_manager.KeyManager):
         symbols = ''.join(symbolgroups)
         password.extend([random.choice(symbols) for _i in range(length)])
 
-        # finally shuffle to ensure first x characters aren't from a
+        # Finally, shuffle to ensure first x characters aren't from a
         # predictable group
         random.shuffle(password)
 
         return ''.join(password)
+
+    def list(self, context, object_type=None, metadata_only=False):
+        """Retrieves a list of managed objects that match the criteria.
+
+        A Forbidden exception is raised if the context is None.
+        If no search criteria is given, all objects are returned.
+        """
+        if context is None:
+            raise exception.Forbidden()
+
+        objects = []
+        for obj_id in self.keys:
+            obj = self.get(context, obj_id, metadata_only=metadata_only)
+            if object_type is None or isinstance(obj, object_type):
+                objects.append(obj)
+        return objects
